@@ -5,7 +5,7 @@
  */
 #include "mockbutton.h"
 
-MockButton::MockButton(KDecoration2::DecorationButtonType type, const QPointer<KDecoration2::Decoration> &decoration, QObject *parent)
+MockButton::MockButton(KDecoration2::DecorationButtonType type, KDecoration2::Decoration *decoration, QObject *parent)
     : DecorationButton(type, decoration, parent)
 {
 }
@@ -15,3 +15,5 @@ void MockButton::paint(QPainter *painter, const QRect &repaintRegion)
     Q_UNUSED(painter)
     Q_UNUSED(repaintRegion)
 }
+
+#include "moc_mockbutton.cpp"
